#  Copyright (C) 2009 Registro.br. All rights reserved.
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
# 1. Redistribution of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
# 
# THIS SOFTWARE IS PROVIDED BY REGISTRO.BR ``AS IS AND ANY EXPRESS OR
# IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIE OF FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
# EVENT SHALL REGISTRO.BR BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
# BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
# OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
# TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
# USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
# DAMAGE.
 
from Response import Response
from ResponseStatus import ResponseStatus
from DsDigestType import DsDigestType

from xml.dom.minidom import parseString
from StringIO import StringIO

class NewZoneResponse(Response):
	"""Response object for the newZone operation (create a new zone)."""
	def __init__(self):
		"""Default constructor"""
		self.zone = ""
		"""Zonename"""
		self.signed = True
		"""Whether the new zone is signed or not"""
		self.keyName = ""
		"""Name of the DNSKEY of the zone (in case it's signed)"""
		self.keytag = 0
		"""Keytag of the DNSKEY of the zone (in case it's signed)"""
		self.digestType = DsDigestType.SHA1
		"""Hash algorithm for the DS digest (in case the zone is signed)"""
		self.digest = ""
		"""DS digest to be included in the parent zone (in case the zone is signed)"""
		self.slaves = []
		"""Zone slaves"""
	
	def __str__(self):
		"""String representation of the object"""
		result = StringIO()
		print >> result, Response.__str__(self)
		if (self.status != ResponseStatus.OK):
			return result.getvalue()
		
		print >> result, "NewZone:"
		print >> result, "\tZone: " + self.zone
		print >> result, "\tKey Name: " + self.keyName
		print >> result, "\tKeytag: " + str(self.keytag)
		print >> result, "\tDS digest: " + self.digest
		print >> result, "\tDigest Type: " + str(self.digestType)
		print >> result, "\tSlaves: " + str(self.slaves)
		return result.getvalue()
    
	def parseXml(self, xml):
		"""
		Parses a response XML document and fills the fields of the current object
		@param xml: Response XML document
		"""
		Response.parseXml(self, xml)
		if (self.status != ResponseStatus.OK):
			return
		
		dom = parseString(xml)

		node = dom.getElementsByTagName("newZone")[0]
		for childNode in node.childNodes:
			nodeName = childNode.nodeName
			if (nodeName == "zone"):
				zone = childNode.firstChild.data
				self.zone = zone
      
			elif (nodeName == "key"):
				keyName = childNode.firstChild.data
				self.keyName = keyName
        
			elif (nodeName == "keytag"):
				keytag = childNode.firstChild.data
				self.keytag = keytag
      
			elif (nodeName == "digest"):
				digest = childNode.firstChild.data
				self.digest = digest
        
			elif (nodeName == "digestType"):
				digestType = childNode.firstChild.data
				self.digestType = digestType

		node = dom.getElementsByTagName("slaves")[0]
		for n in node.childNodes:
			s = {}
			for slave in n.childNodes:

				if (slave.nodeName == "slaveAddress"):
					s['address'] = str(slave.firstChild.data)

				if (slave.nodeName == "slavePort"):
					s['port'] = str(slave.firstChild.data)
					
			self.slaves.append(s)

