#  Copyright (C) 2009 Registro.br. All rights reserved.
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
# 1. Redistribution of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
# 
# THIS SOFTWARE IS PROVIDED BY REGISTRO.BR ``AS IS AND ANY EXPRESS OR
# IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIE OF FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
# EVENT SHALL REGISTRO.BR BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
# BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
# OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
# TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
# USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
# DAMAGE.
 
from RrType import RrType
from DnsClass import DnsClass
from RrOperation import RrOperation
from Cheetah.Template import Template
from RestrictOperation import RestrictOperation;

class RrRequest(RestrictOperation):
	"""Request object for the the addRr and removeRr operations (add or remove a RR from a zone)."""
	ADD_RR_TEMPLATE = """
<?xml version="1.0" encoding="UTF-8"?>
<dnsshim version="1.0">
	<request>
		<addRr>
			<sessionId>$request.sessionId</sessionId>
			<zone>$request.zone</zone>
			<rr>
				<ownername>$request.ownername</ownername>
				<ttl>$request.ttl</ttl>
				<type>$request.type</type>
				<dnsClass>$request.dnsClass</dnsClass>
				<rdata>$request.rdata</rdata>
			</rr>
		</addRr>
	</request>
</dnsshim>
	"""
	"""XML template for the addRR request"""
	
	REMOVE_RR_TEMPLATE = """
<?xml version="1.0" encoding="UTF-8"?>
<dnsshim version="1.0">
	<request>
		<removeRr>
			<sessionId>$request.sessionId</sessionId>
			<zone>$request.zone</zone>
			<rr>
				<ownername>$request.ownername</ownername>
				<ttl>$request.ttl</ttl>
				<type>$request.type</type>
				<dnsClass>$request.dnsClass</dnsClass>
				<rdata>$request.rdata</rdata>
			</rr>
		</removeRr>
	</request>
</dnsshim>
	"""
	"""XML template for the removeRR request"""
	
	def __init__(self):
		"""Default constructor"""
		self.zone = ""
		"""Zonename"""
		self.ownername = ""
		"""Ownername of the RR"""
		self.ttl = 86400
		"""TTL of the RR (default is 86400)"""
		self.type = RrType('NS')
		"""Type of the RR"""
		self.dnsClass = DnsClass.IN
		"""Class of the RR"""
		self.rdata = ""
		"""Rdata in presentation format"""
		self.op = RrOperation.ADD
		"""Operation: either ADD or REMOVE"""
    
	def toXml(self):         
		"""
		Generate the request XML
		@return: Request XML document
		"""
		if (self.op == RrOperation.ADD):
			template = Template(self.ADD_RR_TEMPLATE)
		else:
			template = Template(self.REMOVE_RR_TEMPLATE)
		template.request = self
		return str(template)
