#  Copyright (C) 2009 Registro.br. All rights reserved.
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
# 1. Redistribution of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
# 
# THIS SOFTWARE IS PROVIDED BY REGISTRO.BR ``AS IS AND ANY EXPRESS OR
# IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIE OF FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
# EVENT SHALL REGISTRO.BR BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
# BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
# OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
# TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
# USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
# DAMAGE.
 
from SlaveOperation import SlaveOperation
from Cheetah.Template import Template
from RestrictOperation import RestrictOperation
from RrOperation import RrOperation

class SlaveGroupRequest(RestrictOperation):
	"""Request object for the newSlaveGroup, removeSlaveGroup, assignSlaveGroup and unassignSlaveGroup operations (create or remove a Slavegroup and assign or unassign it from a zone)."""
	NEW_SLAVEGROUP_TEMPLATE = """
<?xml version="1.0" encoding="UTF-8"?>
<dnsshim version="1.0">
	<request>
		<newSlaveGroup>
			<sessionId>$request.sessionId</sessionId>
			<slaveGroup>$request.slaveGroup</slaveGroup>
		</newSlaveGroup>
	</request>
</dnsshim>
	"""
	"""XML template for the newSlaveGroup request"""
	
	REMOVE_SLAVEGROUP_TEMPLATE = """
<?xml version="1.0" encoding="UTF-8"?>
<dnsshim version="1.0">
	<request>
		<removeSlaveGroup>
			<sessionId>$request.sessionId</sessionId>
			<slaveGroup>$request.slaveGroup</slaveGroup>
		</removeSlaveGroup>
	</request>
</dnsshim>
	"""
	"""XML template for the removeSlaveGroup request"""
	
	ASSIGN_SLAVEGROUP_TEMPLATE = """
<?xml version="1.0" encoding="UTF-8"?>
<dnsshim version="1.0">
	<request>
		<assignSlaveGroup>
			<sessionId>$request.sessionId</sessionId>
			<zone>$request.zone</zone>
			<slaveGroup>$request.slaveGroup</slaveGroup>
		</assignSlaveGroup>
	</request>
</dnsshim>
	"""
	"""XML template for the assignSlaveGroup request"""
	
	UNASSIGN_SLAVEGROUP_TEMPLATE = """
<?xml version="1.0" encoding="UTF-8"?>
<dnsshim version="1.0">
	<request>
		<unassignSlaveGroup>
			<sessionId>$request.sessionId</sessionId>
			<zone>$request.zone</zone>
			<slaveGroup>$request.slaveGroup</slaveGroup>
		</unassignSlaveGroup>
	</request>
</dnsshim>
	"""
	"""XML template for the unassignSlaveGroup request"""
	
	def __init__(self):
		"""Default constructor"""
		self.zone = ""
		"""Zonename (applicable only to the ASSIGN and UNASSIGN operations)"""
		self.slaveGroup = ""
		"""Slavegroup name"""
		self.operation = SlaveOperation.ADD
		"""Operation to be executed: ADD, REMOVE, ASSIGN or UNASSIGN"""
	
	def toXml(self):         
		"""
		Generate the request XML
		@return: Request XML document
		"""
		if (self.operation == SlaveOperation.ADD):
			template = Template(self.NEW_SLAVEGROUP_TEMPLATE)
		elif (self.operation == SlaveOperation.REMOVE):
			template = Template(self.REMOVE_SLAVEGROUP_TEMPLATE)
		elif (self.operation == SlaveOperation.ASSIGN):
			template = Template(self.ASSIGN_SLAVEGROUP_TEMPLATE)
		elif (self.operation == SlaveOperation.UNASSIGN):
			template = Template(self.UNASSIGN_SLAVEGROUP_TEMPLATE)
		template.request = self
		return str(template)
