#  Copyright (C) 2009 Registro.br. All rights reserved.
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
# 1. Redistribution of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
# 
# THIS SOFTWARE IS PROVIDED BY REGISTRO.BR ``AS IS AND ANY EXPRESS OR
# IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIE OF FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
# EVENT SHALL REGISTRO.BR BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
# BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
# OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
# TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
# USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
# DAMAGE.
 
import socket
import struct

import sys
pyversion = sys.version_info[0]*10 + sys.version_info[1]
if (pyversion >= 26):
	import ssl
	
class TransportException(Exception):
	"""Transport exception class"""
	def __init__(self, msg = ''):
		"""Default constructor"""
		self.msg = msg
	
	def __str__(self):
		"""String representation (message)"""
		return self.msg
	
class Transport:
	"""Transport class"""
	def __init__(self, server, port):
		"""Default constructor"""
		self.server = server
		"""IP address of the DNSSHIM server"""
		self.port = port
		"""Port number of the DNSSHIM server"""
		
	def sendRequest(self, xml):
		"""
		Send a request XML document to the DNSSHIM server and receive the response
		@param xml: request XML document
		@return: response XML document
		"""
		bufLen = struct.pack('!I', len(xml))
		buf = bufLen + xml
		try:
			s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
			s.connect((self.server, self.port))
			if (pyversion >= 26):
				sslSocket = ssl.wrap_socket(s)
			else:
				sslSocket = socket.ssl(s)

			sslSocket.write(buf)
			buf = sslSocket.read(4)
			totalLen = struct.unpack('!I', buf)[0]
			remaining = totalLen
			response = ''
			while (remaining > 0):
				buf = sslSocket.read(remaining)
				response += buf
				remaining -= len(buf)
			
			if (pyversion >= 26):
				sslSocket.close()
			else:
				s.close()
		except:
			raise TransportException("Error communicating to server")
		return response
